NavigationService class

Constructors

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

currentContext → BuildContext?
no setter
no setter
getter/setter pair

Static Methods

pop<T>([T? result]) → void
popUntil(String routeName) → void
push<T>(Widget page, {String? routeName}) → Future<T?>
pushAndRemoveUntil<T>(Widget page, {String? routeName, bool predicate(Route)?}) → Future<T?>
pushNamed<T>(String routeName, {Object? arguments}) → Future<T?>
pushReplacement<T, TO>(Widget page, {String? routeName}) → Future<T?>