CalendarPickerDialog class

Inheritance

Constructors

CalendarPickerDialog({Key? key, required CalendarPickerMode mode, required DateTime initialDate, required DateTime firstDate, required DateTime lastDate, DateTime? initialRangeStart, DateTime? initialRangeEnd, List<DateTime>? initialSelectedDates, List<DateTime>? disabledDates, required Color primaryColor, required Color selectedColor, required Color todayColor, required String title, required String confirmButtonText, required String cancelButtonText})
const

Properties

cancelButtonText → String
final
confirmButtonText → String
final
disabledDates → List<DateTime>?
final
firstDate → DateTime
final
hashCode → int
The hash code for this object.
no setterinherited
initialDate → DateTime
final
initialRangeEnd → DateTime?
final
initialRangeStart → DateTime?
final
initialSelectedDates → List<DateTime>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lastDate → DateTime
final
mode → CalendarPickerMode
final
primaryColor → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedColor → Color
final
title → String
final
todayColor → Color
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CalendarPickerDialogState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited