CropSettings class

Constructors

CropSettings({CropAspectRatio? aspectRatio, CropStyle cropStyle = CropStyle.rectangle, int compressQuality = 90, ImageCompressFormat compressFormat = ImageCompressFormat.jpg, String toolbarTitle = 'Crop Image', Color toolbarColor = const Color(0xFF2196F3), Color toolbarWidgetColor = Colors.white, Color backgroundColor = Colors.black, Color primaryColor = const Color(0xFF2196F3), CropAspectRatioPreset initAspectRatio = CropAspectRatioPreset.original, bool lockAspectRatio = false, bool hideBottomControls = false})
CropSettings.coverPhoto({int compressQuality = 85, Color primaryColor = const Color(0xFF2196F3), Color backgroundColor = Colors.black})
factory
CropSettings.profilePicture({int compressQuality = 85, Color primaryColor = const Color(0xFF2196F3), Color backgroundColor = Colors.black})
factory
CropSettings.square({int compressQuality = 90, Color primaryColor = const Color(0xFF2196F3), Color backgroundColor = Colors.black})
factory

Properties

aspectRatio → CropAspectRatio?
final
backgroundColor → Color
final
compressFormat → ImageCompressFormat
final
compressQuality → int
final
cropStyle → CropStyle
final
hashCode → int
The hash code for this object.
no setterinherited
hideBottomControls → bool
final
initAspectRatio → CropAspectRatioPreset
final
lockAspectRatio → bool
final
primaryColor → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolbarColor → Color
final
toolbarTitle → String
final
toolbarWidgetColor → Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited