ScannerTheme class

Constructors

ScannerTheme({required Color primaryColor, Color overlayColor = const Color(0x88000000), double scanAreaWidth = 260, double scanAreaHeight = 260, double cornerSize = 40})

Properties

cornerSize → double
final
hashCode → int
The hash code for this object.
no setterinherited
overlayColor → Color
final
primaryColor → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanAreaHeight → double
final
scanAreaWidth → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited