BoltPDFViewer class

Inheritance

Constructors

BoltPDFViewer({Key? key, String? filePath, String? url, String? assetPath, PDFViewSource source = PDFViewSource.file, bool enableNavigation = true, bool showPageCounter = true, bool showToolbar = true, bool enableTextSelection = true, String? password, int defaultPage = 0, Color? loadingColor, String? title, List<Widget>? toolbarActions, Widget? loadingWidget, Widget? errorWidget, Color? backgroundColor, dynamic onViewCreated(PDFViewController)?, dynamic onPageChanged(int)?, dynamic onError(dynamic)?, bool isModal = false, IconData? fabIcon, VoidCallback? onFabPressed})
const

Properties

assetPath → String?
Asset path for PDF assets
final
backgroundColor → Color?
final
defaultPage → int
final
enableNavigation → bool
Whether to enable PDF page navigation
final
enableTextSelection → bool
Whether to enable text selection
final
errorWidget → Widget?
final
fabIcon → IconData?
FAB icon to display
final
filePath → String?
File path for local files
final
hashCode → int
The hash code for this object.
no setterinherited
isModal → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingColor → Color?
final
loadingWidget → Widget?
final
onError → dynamic Function(dynamic)?
final
onFabPressed → VoidCallback?
Function to execute when FAB is pressed
final
onPageChanged → dynamic Function(int)?
final
onViewCreated → dynamic Function(PDFViewController)?
final
password → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showPageCounter → bool
Whether to show the page counter
final
showToolbar → bool
Whether to show toolbar with actions
final
source → PDFViewSource
Source type of the PDF
final
title → String?
final
toolbarActions → List<Widget>?
final
url → String?
URL for network PDFs
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<BoltPDFViewer>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

openPdf({required BuildContext context, String? filePath, String? url, String? assetPath, PDFViewSource source = PDFViewSource.file, String? title, bool enableNavigation = true, bool enableTextSelection = true, IconData? fabIcon, VoidCallback? onFabPressed}) → Future<void>
showPdfDialog({required BuildContext context, String? filePath, String? url, String? assetPath, PDFViewSource source = PDFViewSource.file, String? title, bool barrierDismissible = true, bool enableNavigation = true, bool enableTextSelection = true, IconData? fabIcon, VoidCallback? onFabPressed}) → Future<void>