AppColors class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- accent ↔ Color
-
getter/setter pair
- background ↔ Color
-
getter/setter pair
- card ↔ Color
-
getter/setter pair
- darkBackground ↔ Color
-
getter/setter pair
- darkBorder ↔ Color
-
getter/setter pair
- darkSurface ↔ Color
-
getter/setter pair
- error ↔ Color
-
getter/setter pair
- info ↔ Color
-
getter/setter pair
- lightBackground ↔ Color
-
getter/setter pair
- lightBorder ↔ Color
-
getter/setter pair
- lightSurface ↔ Color
-
getter/setter pair
- primary ↔ Color
-
getter/setter pair
- success ↔ Color
-
getter/setter pair
- text ↔ Color
-
getter/setter pair
- textLight ↔ Color
-
getter/setter pair
- warning ↔ Color
-
getter/setter pair
Static Methods
-
generatePrimaryShades(
) → Map< int, Color> -
getByBrightness(
Brightness brightness, {required Color light, required Color dark}) → Color -
initialize(
{required Color primary, required Color accent, Color? background, Color? card, Color? text, Color? textLight, Color? error, Color? success, Color? warning, Color? info}) → void